@@ -6,14 +6,14 @@ use base 'Exporter';
 
 our @EXPORT = qw/canon_path canon_filepath/;
 
-our $VERSION = "0.04";
+our $VERSION = "0.05";
 
 sub canon_filepath {
     my $path = shift;
     return canon_path($path) if $^O ne 'MSWin32';
     $path =~ s!\\!/!g;
     $path =~ s!^([a-zA-Z]:|//[^/]+/+[^/]+)!!g;
-    $path = $& . canon_path($path);
+    $path = ($&||'') . canon_path($path);
     $path =~ s!/!\\!g;
     $path;
 }
